@@ -22,6 +22,8 @@ import traceback
 from datetime import datetime, timedelta
 from collections import deque
 
+from six import add_metaclass
+
 from logbook.base import CRITICAL, ERROR, WARNING, NOTICE, INFO, DEBUG, \
      NOTSET, level_name_property, _missing, lookup_level, \
      Flags, ContextObject, ContextStackManager
@@ -105,6 +107,7 @@ class _HandlerType(type):
         return type.__new__(cls, name, bases, d)
 
 
+@add_metaclass(_HandlerType)
 class Handler(ContextObject):
     """Handler instances dispatch logging events to specific destinations.
 
@@ -125,16 +128,7 @@ class Handler(ContextObject):
 
     By default messages sent to that handler will not go to a handler on
     an outer level on the stack, if handled.  This can be changed by
-    setting bubbling to `True`.  This setup for example would not have
-    any effect::
-
-        handler = NullHandler(bubble=True)
-        handler.push_application()
-
-    Whereas this setup disables all logging for the application::
-
-        handler = NullHandler()
-        handler.push_application()
+    setting bubbling to `True`.
 
     There are also context managers to setup the handler for the duration
     of a `with`-block::
@@ -156,8 +150,6 @@ class Handler(ContextObject):
 
     If gevent is enabled, the handler is aliased to `greenletbound`.
     """
-    __metaclass__ = _HandlerType
-
     stack_manager = ContextStackManager()
 
     #: a flag for this handler that can be set to `True` for handlers that
@@ -303,8 +295,15 @@ class Handler(ContextObject):
 
 
 class NullHandler(Handler):
-    """A handler that does nothing, meant to be inserted in a handler chain
-    with ``bubble=False`` to stop further processing.
+    """A handler that does nothing.
+
+    Useful to silence logs above a certain location in the handler stack::
+
+        handler = NullHandler()
+        handler.push_application()
+
+    NullHandlers swallow all logs sent to them, and do not bubble them onwards.
+
     """
     blackhole = True
 
